pub(crate) struct GetSchemaInput {
pub table: Option<String>,
}Fields
table: Option<String>Trait Implementations
Sourceimpl Debug for GetSchemaInput
impl Debug for GetSchemaInput
Sourceimpl Default for GetSchemaInput
impl Default for GetSchemaInput
Sourcefn default() -> GetSchemaInput
fn default() -> GetSchemaInput
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetSchemaInput
impl<'de> Deserialize<'de> for GetSchemaInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetSchemaInput
impl JsonSchema for GetSchemaInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetSchemaInput
impl RefUnwindSafe for GetSchemaInput
impl Send for GetSchemaInput
impl Sync for GetSchemaInput
impl Unpin for GetSchemaInput
impl UnsafeUnpin for GetSchemaInput
impl UnwindSafe for GetSchemaInput